<?php
/* $Id: persistens.php 74 2010-06-13 10:14:34Z mir $ */

include_once 'config.inc.php';

require_once 'sqlite.php';
require_once 'pgsql.php';

class DefaultConfig {
    public $viewStyle;
    public $timeout;
    public $startWeek;
    public $startHour;
    public $endHour;
    public $title;
    public $timezone;
    public $errorDisplay;
    public $errorLog;
    public $logFile;
    public $topFolder;
    public $webRoot;
    public $dns;
    public $role;
}

interface WebcalSupport {
    function getViewStyle($uid);
    function getTimeout($uid);
    function getRole($uid);
    function getStartWeek($uid);
    function getStartHour($uid);
    function getEndHour($uid);
    function getTimezone($uid);
    function authenticate($uid, $pwd);
    function createDatabase($name);
    function initDatabase($name, $pwd, $uid);
    function addUser($data);
    function setUserSettings($uid, $data);
    function deleteUser($uid);
    function addCalendar($uid, CalendarInfo $calendar);
    function deleteCalendar($uid, $id);
    function updateCalendar($uid, $id, CalendarInfo $calendar);
    function changePassword($uid, $pwd);
    function getAllUsers($limit, $offset);
    function getRoles();
    function getRoleName($id);
    function changeDefault($data);
    function getVersion();
    function execute($sql);
    function getCalendarConfig($id);
    function nextTableNumber($name);
}

class Persistens {

    private static $instance = NULL;
    private $con;

    private function __construct($driver, $dns) {
        $this->con = new $driver($dns);
    }

    private function __clone() {}

    static function getInstance($db = NULL, $dns = NULL) {
        if (! self::$instance) {
            if (! $db)
                throw new Exception('Missing database driver');
            switch (strtolower($db)) {
                case 'sqlite':
                    self::$instance = new Persistens('SQLite', $dns); break;
                    break;
                case 'pgsql':
                    self::$instance = new Persistens('Pgsql', $dns); break;
                    break;
                default: throw new Exception("$db: Unsupported driver");
            }
        }
        return self::$instance;
    }

    function getViewStyle($uid) {
        return $this->con->getViewStyle($uid);
    }

    function getStartWeek($uid) {
    }

    function getStartHour($uid) {
    }

    function getEndHour($uid) {
    }

    function authenticate($uid, $pwd) {
        return $this->con->authenticate($uid, sha1($pwd));
    }

    function getTimeout($uid) {
    }

    function getRole($uid) {
    }

    function createDatabase($name) {
        $this->con->createDatabase($name);
    }

    function initDatabase($name, $pwd, $uid = 'webcal') {
        $this->con->initDatabase($name, $pwd, $uid = 'webcal');
        $this->con = NULL;
        self::$instance = NULL;
    }

    function newUser($data) {
        return $this->con->addUser($data);
    }

    function setUserSettings($uid, $settings) {
        return $this->con->setUserSettings($uid, $settings);
    }

    function deleteUser($uid) {
        return $this->con->deleteUser($uid);
    }

    function addCalendar($uid, CalendarInfo $calendar) {
        return $this->con->addCalendar($uid, $calendar);
    }

    function deleteCalendar($uid, $id) {
        return $this->con->deleteCalendar($uid, $id);
    }

    function updateCalendar($uid, $id, CalendarInfo $calendar) {
        return $this->con->updateCalendar($uid, $id, $calendar);
    }

    function changePassword($uid, $pwd) {
        return $this->con->changePassword($uid, $pwd);
    }

    function getAllUsers($limit = -1, $offset = 0) {
        return $this->con->getAllUsers($limit, $offset);
    }

    function getRoles() {
        return $this->con->getRoles();
    }

    function getRoleName($id) {
        return $this->con->getRoleName($id);
    }

    function changeDefault($data) {
        return $this->con->changeDefault($data);
    }
    
    function getVersion() {
        $res = $this->con->getVersion();
        if (! is_array($res))
            throw new Exception($res);
        return $res;
    }

    function execute($sql) {
        return $this->con->execute($sql);
    }
    
    function getCalendarConfig($id = -1) {
		return $this->con->getCalendarConfig($id);
	}

	function nextTableNumber($name) {
		return $this->con->nextTableNumber($name);
	}
	
}

?>
